summaryrefslogtreecommitdiffstats
path: root/googletest/src
diff options
context:
space:
mode:
authorGennadiy Civil <misterg@google.com>2019-02-04 19:19:29 (GMT)
committerGennadiy Civil <misterg@google.com>2019-02-04 19:19:31 (GMT)
commit471f5bc433c00fcd0ba778c3f96c91039043cfaa (patch)
tree18a72bd6540e8e3ffad9bbd4d62ff1e70d1b6202 /googletest/src
parent0ea2d8f8fa1601abb9ce713b7414e7b86f90bc61 (diff)
parent53798de93935e463782707bd0b8bdc0d0dd7e185 (diff)
downloadgoogletest-471f5bc433c00fcd0ba778c3f96c91039043cfaa.zip
googletest-471f5bc433c00fcd0ba778c3f96c91039043cfaa.tar.gz
googletest-471f5bc433c00fcd0ba778c3f96c91039043cfaa.tar.bz2
Merge pull request #2098 from ciband:feat/finish_platformio_support
PiperOrigin-RevId: 232028696
Diffstat (limited to 'googletest/src')
-rw-r--r--googletest/src/gtest-filepath.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/googletest/src/gtest-filepath.cc b/googletest/src/gtest-filepath.cc
index 204d460..499ec58 100644
--- a/googletest/src/gtest-filepath.cc
+++ b/googletest/src/gtest-filepath.cc
@@ -92,8 +92,9 @@ static bool IsPathSeparator(char c) {
// Returns the current working directory, or "" if unsuccessful.
FilePath FilePath::GetCurrentDir() {
-#if GTEST_OS_WINDOWS_MOBILE || GTEST_OS_WINDOWS_PHONE || GTEST_OS_WINDOWS_RT
- // Windows CE doesn't have a current directory, so we just return
+#if GTEST_OS_WINDOWS_MOBILE || GTEST_OS_WINDOWS_PHONE || \
+ GTEST_OS_WINDOWS_RT || ARDUINO
+ // Windows CE and Arduino don't have a current directory, so we just return
// something reasonable.
return FilePath(kCurrentDirectoryString);
#elif GTEST_OS_WINDOWS